==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebTreeGridDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarDescriptionMetadata } from "./WebGridToolbarDescriptionMetadata";
import { WebGridToolbarActionsDescriptionMetadata } from "./WebGridToolbarActionsDescriptionMetadata";
import { WebGridToolbarTitleDescriptionMetadata } from "./WebGridToolbarTitleDescriptionMetadata";
import { WebGridToolbarExporterDescriptionMetadata } from "./WebGridToolbarExporterDescriptionMetadata";
import { WebGridToolbarHidingDescriptionMetadata } from "./WebGridToolbarHidingDescriptionMetadata";
import { WebGridToolbarPinningDescriptionMetadata } from "./WebGridToolbarPinningDescriptionMetadata";
import { WebGridToolbarAdvancedFilteringDescriptionMetadata } from "./WebGridToolbarAdvancedFilteringDescriptionMetadata";
import { WebGridToolbarBaseActionDescriptionMetadata } from "./WebGridToolbarBaseActionDescriptionMetadata";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebTreeGridRecordDescriptionMetadata } from "./WebTreeGridRecordDescriptionMetadata";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebTreeGridDescription } from "./WebTreeGridDescription";
/**
 * @hidden
 */
export let WebTreeGridDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeGridDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeGridDescriptionMetadata.a == null) {
                WebTreeGridDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeGridDescriptionMetadata.c(WebTreeGridDescriptionMetadata.a);
            }
            if (a.j(WebTreeGridDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTreeGridDescriptionMetadata.a);
            WebTreeGridDescriptionMetadata.f(a);
            WebTreeGridRecordDescriptionMetadata.d(a);
        }
        static c(a) {
            WebGridBaseDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:TreeGrid");
            a.item("__tagNameWC", "String:igc-tree-grid");
            a.item("__packageNameWC", "String:grids");
            a.item("ChildDataKey", "String");
            a.item("ForeignKey", "String");
            a.item("HasChildrenKey", "String");
            a.item("CascadeOnDelete", "Boolean");
            a.item("Id", "String");
            a.item("RootRecords", "Array:WebTreeGridRecordDescription:TreeGridRecord");
            a.item("ProcessedRootRecords", "Array:WebTreeGridRecordDescription:TreeGridRecord");
            a.item("DataRef", "(w:Data,wf:Data)DataRef::object");
            a.item("FilteredData", "Unknown");
            a.item("ExpansionDepth", "Number:double");
            a.item("RowLoadingIndicatorTemplateRef", "(w:RowLoadingIndicatorTemplate,wf:RowLoadingIndicatorTemplate)TemplateRef::object");
            WebTreeGridDescriptionMetadata.e(a);
        }
        static d(a) {
            WebTreeGridDescriptionMetadata.b(a);
            a.aa("WebTreeGrid", () => new WebTreeGridDescription());
            a.z("WebTreeGrid", WebTreeGridDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__deferAttachWC", "Boolean");
        }
        static f(a) {
            WebGridToolbarDescriptionMetadata.d(a);
            WebGridToolbarActionsDescriptionMetadata.d(a);
            WebGridToolbarTitleDescriptionMetadata.d(a);
            WebGridToolbarExporterDescriptionMetadata.d(a);
            WebGridToolbarHidingDescriptionMetadata.d(a);
            WebGridToolbarPinningDescriptionMetadata.d(a);
            WebGridToolbarAdvancedFilteringDescriptionMetadata.d(a);
            WebGridToolbarBaseActionDescriptionMetadata.d(a);
            WebGridToolbarContentDescriptionMetadata.d(a);
        }
    }
    WebTreeGridDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTreeGridDescriptionMetadata, 'WebTreeGridDescriptionMetadata');
    WebTreeGridDescriptionMetadata.a = null;
    return WebTreeGridDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebTreeGridDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarDescriptionMetadata } from "./WebGridToolbarDescriptionMetadata";
import { WebGridToolbarActionsDescriptionMetadata } from "./WebGridToolbarActionsDescriptionMetadata";
import { WebGridToolbarTitleDescriptionMetadata } from "./WebGridToolbarTitleDescriptionMetadata";
import { WebGridToolbarExporterDescriptionMetadata } from "./WebGridToolbarExporterDescriptionMetadata";
import { WebGridToolbarHidingDescriptionMetadata } from "./WebGridToolbarHidingDescriptionMetadata";
import { WebGridToolbarPinningDescriptionMetadata } from "./WebGridToolbarPinningDescriptionMetadata";
import { WebGridToolbarAdvancedFilteringDescriptionMetadata } from "./WebGridToolbarAdvancedFilteringDescriptionMetadata";
import { WebGridToolbarBaseActionDescriptionMetadata } from "./WebGridToolbarBaseActionDescriptionMetadata";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebTreeGridRecordDescriptionMetadata } from "./WebTreeGridRecordDescriptionMetadata";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebTreeGridDescription } from "./WebTreeGridDescription";
/**
 * @hidden
 */
export let WebTreeGridDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeGridDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeGridDescriptionMetadata.a == null) {
                WebTreeGridDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeGridDescriptionMetadata.c(WebTreeGridDescriptionMetadata.a);
            }
            if (a.k(WebTreeGridDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebTreeGridDescriptionMetadata.a);
            WebTreeGridDescriptionMetadata.f(a);
            WebTreeGridRecordDescriptionMetadata.d(a);
        }
        static c(a) {
            WebGridBaseDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:TreeGrid");
            a.item("__tagNameWC", "String:igc-tree-grid");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            if (a.containsKey("__skipSuffix")) {
                a.removeItem("__skipSuffix");
            }
            a.item("ChildDataKey", "String");
            a.item("ForeignKey", "String");
            a.item("HasChildrenKey", "String");
            a.item("CascadeOnDelete", "Boolean");
            a.item("Id", "String");
            a.item("RootRecords", "Array:WebTreeGridRecordDescription:TreeGridRecord");
            a.item("ProcessedRootRecords", "Array:WebTreeGridRecordDescription:TreeGridRecord");
            a.item("DataRef", "(w:Data,wf:Data)DataRef::object");
            a.item("FilteredData", "Unknown");
            a.item("ExpansionDepth", "Number:double");
            a.item("RowLoadingIndicatorTemplateRef", "(w:RowLoadingIndicatorTemplate,wf:RowLoadingIndicatorTemplate)TemplateRef::object");
            WebTreeGridDescriptionMetadata.e(a);
        }
        static d(a) {
            WebTreeGridDescriptionMetadata.b(a);
            a.ac("WebTreeGrid", () => new WebTreeGridDescription());
            a.ab("WebTreeGrid", WebTreeGridDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__deferAttachWC", "Boolean");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        }
        static f(a) {
            WebGridToolbarDescriptionMetadata.d(a);
            WebGridToolbarActionsDescriptionMetadata.d(a);
            WebGridToolbarTitleDescriptionMetadata.d(a);
            WebGridToolbarExporterDescriptionMetadata.d(a);
            WebGridToolbarHidingDescriptionMetadata.d(a);
            WebGridToolbarPinningDescriptionMetadata.d(a);
            WebGridToolbarAdvancedFilteringDescriptionMetadata.d(a);
            WebGridToolbarBaseActionDescriptionMetadata.d(a);
            WebGridToolbarContentDescriptionMetadata.d(a);
        }
    }
    WebTreeGridDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTreeGridDescriptionMetadata, 'WebTreeGridDescriptionMetadata');
    WebTreeGridDescriptionMetadata.a = null;
    return WebTreeGridDescriptionMetadata;
})();
